## 简介

1、封装PyMySQL使用的集合类
- 读取配置文件
- 创建连接
- 创建游标

2、新增公用读取配置文件的方法
- 支持从多个位置加载 YAML/JSON/CONF 格式的配置文件
- 支持从环境变量/工作目录/用户目录中加载配置文件
- 支持从多个配置文件中加载指定环境的配置
- 支持类型转换和必填字段校验

3、新增日志记录器
- 支持多处理器、配置文件、异常捕获的增强型日志记录器
- 支持多种日志格式（标准、JSON）
- 支持多种日志级别（DEBUG、INFO、WARNING、ERROR、CRITICAL）
- 支持多种日志输出方式（控制台、文件）
- 支持多种日志滚动策略（按时间、按大小）


## 使用方法
后续添加

## 日志

- 2026-03-17
    - 新增日志记录器

- 2026-03-10
    - tags v1.0.0
    - utils 新增config文件夹，默认放配置文件

- 2026-02-25 MySQLClient 新增 is_connected 方法
